@@ -1,5 +1,8 @@
 
 
+CMD_BASE = ('check', 'create', 'delete', 'info', 'login', 'logout', 'poll', 'renew', 'transfer', 'update',  # one of
+            'extension', 'clTRID')
+
 CMD_LOGIN = ('clID',
              'pw',
              'newPW',
@@ -22,6 +25,7 @@ CMD_UPDATE_CONTACT = ('id', 'add', 'rem', 'chg')
 CMD_UPDATE_CONTACT_CHG = ('postalInfo', 'voice', 'fax', 'email', 'authInfo', 'disclose')
 
 CMD_TRANSFER_DOMAON = ('name', 'period', 'authInfo')
+CMD_TRANSFER_CONTACT = ('id', 'period', 'authInfo')
 
 POSTAL_INFO = (
     'name',
